@@ -1,9 +1,9 @@
 #include <iostream>
 
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
-#include "zypp/ZYppFactory.h"
-#include "zypp/RepoManager.h"
+#include <zypp/ZYppFactory.h>
+#include <zypp/RepoManager.h>
 #include "TestSetup.h"
 
 using namespace boost::unit_test;
@@ -11,7 +11,15 @@ using namespace zypp;
 using std::cout;
 using std::endl;
 
-TestSetup test( Arch_x86_64 );
+static TestSetup test( TestSetup::initLater );
+struct TestInit {
+  TestInit() {
+    test = TestSetup( Arch_x86_64 );
+  }
+  ~TestInit() { test.reset(); }
+};
+BOOST_GLOBAL_FIXTURE( TestInit );
+
 const Pathname DATADIR( TESTS_SRC_DIR "/repo/RepoLicense" );
 
 ///////////////////////////////////////////////////////////////////
