@@ -1,22 +1,28 @@
 #include "TestSetup.h"
-#include "zypp/ResPool.h"
-#include "zypp/ui/Selectable.h"
+#include <zypp/ResPool.h>
+#include <zypp/ui/Selectable.h>
 
 #define BOOST_TEST_MODULE Selectable
 
 /////////////////////////////////////////////////////////////////////////////
 
-static TestSetup test;
+static TestSetup test( TestSetup::initLater );
+struct TestInit {
+  TestInit() {
+    test = TestSetup( );
 
-BOOST_AUTO_TEST_CASE(testcase_init)
-{
-//   zypp::base::LogControl::instance().logToStdErr();
-  test.loadTestcaseRepos( TESTS_SRC_DIR"/data/TCSelectable" );
+    //   zypp::base::LogControl::instance().logToStdErr();
+    test.loadTestcaseRepos( TESTS_SRC_DIR"/data/TCSelectable" );
+
+    //   dumpRange( USR, test.pool().knownRepositoriesBegin(),
+    //                   test.pool().knownRepositoriesEnd() ) << endl;
+    //   USR << "pool: " << test.pool() << endl;
+
+  }
+  ~TestInit() { test.reset(); }
+};
+BOOST_GLOBAL_FIXTURE( TestInit );
 
-//   dumpRange( USR, test.pool().knownRepositoriesBegin(),
-//                   test.pool().knownRepositoriesEnd() ) << endl;
-//   USR << "pool: " << test.pool() << endl;
-}
 /////////////////////////////////////////////////////////////////////////////
 
 BOOST_AUTO_TEST_CASE(candiadate)
