@@ -812,20 +812,20 @@ namespace zypp
           else
           {
             std::string toadd( asString(*iter) );
-            for_( ch, toadd.begin(), toadd.end() )
+            for ( const char ch : toadd )
             {
-              switch ( *ch )
+              switch ( ch )
               {
                 case '"':
                 case '\'':
                 case '\\':
                   buf.push_back( '\\' );
-                  buf.push_back( *ch );
+                  buf.push_back( ch );
                   break;
                 default:
-                  if ( *ch == sep_r )
+                  if ( ch == sep_r )
                     buf.push_back( '\\' );
-                  buf.push_back( *ch );
+                  buf.push_back( ch );
               }
             }
           }
@@ -851,11 +851,11 @@ namespace zypp
           else
             maxWitdh_r -= indent_r.size();
         }
-        unsigned width = 0;
+
         for ( const char * e = text_r.c_str(), * s = e; *e; s = ++e )
         {
           for ( ; *e && *e != '\n'; ++e ) ;/*searching*/
-          width = e-s;
+          unsigned width = e-s;
           if ( maxWitdh_r && width > maxWitdh_r )
           {
             // must break line
