@@ -12,6 +12,7 @@
 #ifndef   ZYPP_URL_URLBASE_H
 #define   ZYPP_URL_URLBASE_H
 
+#include <set>
 #include <zypp-core/url/UrlUtils.h>
 #include <zypp-core/base/PtrTypes.h>
 
@@ -849,11 +850,12 @@ namespace zypp
       /**
        * \brief Set the query parameters.
        * \param qmap The map with decoded query parameters.
+       * \param eflag Tells whether keys and values in pmap are already encoded or decoded.
        * \throws UrlNotSupportedException if parameter parsing
        *         is not supported for a URL (scheme).
        */
       virtual void
-      setQueryStringMap(const zypp::url::ParamMap &qmap);
+      setQueryStringMap(const zypp::url::ParamMap &qmap, EEncoding eflag);
 
       /**
        * \brief Set or add value for the specified query parameter.
@@ -878,6 +880,8 @@ namespace zypp
       virtual void
       delQueryParam(const std::string &param);
 
+      void
+      delQueryParams(const std::set<std::string> &params);
 
       // -----------------
       /**
