@@ -322,6 +322,13 @@ void fillSettingsFromUrl( const Url &url, media::TransferSettings &s )
     if( ! param.empty() && param == "no" )
       s.setHeadRequestsAllowed( false );
   }
+  {
+    const auto &cookieFileParam = url.getQueryParam( "cookies" );
+    if ( !cookieFileParam.empty() && str::strToBool( cookieFileParam, true ) )
+      s.setEnableCookieFile ( true );
+    else
+      s.setEnableCookieFile ( false );
+  }
 }
 
 /**
@@ -394,6 +401,7 @@ Url clearQueryString(const Url &url)
     "mediahandler",
     "credentials",
     "head_requests",
+    "mediahandler",
   } );
   return curlUrl;
 }
