@@ -335,7 +335,7 @@ MediaBlockList::checkRsum(size_t blkno, const unsigned char *buf, size_t bufl) c
 {
   if (blkno >= blocks.size() || bufl < blocks[blkno].size)
     return false;
-  unsigned int rs = updateRsum(0, (const char *)buf, blocks[blkno].size);
+  unsigned int rs = updateRsum(0, reinterpret_cast<const char*>(buf), blocks[blkno].size);
   return verifyRsum(blkno, rs);
 }
 
@@ -347,7 +347,7 @@ MediaBlockList::checkChecksum(size_t blkno, const unsigned char *buf, size_t buf
   Digest dig;
   if (!createDigest(dig))
     return false;
-  dig.update((const char *)buf, blocks[blkno].size);
+  dig.update(reinterpret_cast<const char*>(buf), blocks[blkno].size);
   return verifyDigest(blkno, dig);
 }
 
@@ -384,9 +384,9 @@ MediaBlockList::checkChecksumRotated(size_t blkno, const unsigned char *buf, siz
     return false;
   size_t size = blocks[blkno].size;
   size_t len = bufl - start > size ? size : bufl - start;
-  dig.update((const char *)buf + start, len);
+  dig.update(reinterpret_cast<const char*>(buf) + start, len);
   if (size > len)
-    dig.update((const char *)buf, size - len);
+    dig.update(reinterpret_cast<const char*>(buf), size - len);
   return verifyDigest(blkno, dig);
 }
 
@@ -415,7 +415,6 @@ static size_t
 fetchnext(FILE *fp, unsigned char *bp, size_t blksize, size_t pushback, unsigned char *pushbackp)
 {
   size_t l = blksize;
-  int c = 0;
 
   if (pushback)
     {
@@ -426,7 +425,7 @@ fetchnext(FILE *fp, unsigned char *bp, size_t blksize, size_t pushback, unsigned
     }
   while (l)
     {
-      c = getc(fp);
+      int c = getc(fp);
       if (c == EOF)
         break;
       *bp++ = c;
@@ -493,14 +492,14 @@ void MediaBlockList::reuseBlocks(FILE *wfp, const std::string& filename)
       // build the hashtable
       uint rsumHashMask = 0;
       {
-        int i = 16;
+        uint i = 16;
 
         /* Try hash size of 2^i; step down the value of i until we find a good size */
-        while ((2 << (i - 1)) > nblks && i > 4)
+        while ((2U << (i - 1)) > nblks && i > 4)
           i--;
 
         /* Allocate hash based on rsum */
-        rsumHashMask = (2 << i) - 1;
+        rsumHashMask = (2U << i) - 1;
       }
 
       // a array indexed via hash with lists of blocks resulting in the same rsum hash
