@@ -296,11 +296,12 @@ namespace zyppng {
           case ProvideMessage::Code::ExpectedSizeExceeded: {
 
             std::optional<int64_t> filesize;
-            finishedReq->provideMessage ().forEachVal( [&]( const std::string &key, const auto &val ){
-              if ( key == ProvideMsgFields::ExpectedFilesize && val.valid() )
+            const auto &hdrs = finishedReq->provideMessage ().headers ();
+            if ( hdrs.contains( ProvideMsgFields::ExpectedFilesize ) ) {
+              const auto &val = hdrs.value ( ProvideMsgFields::ExpectedFilesize );
+              if ( val.valid() )
                 filesize = val.asInt64();
-              return true;
-            });
+            }
 
             if ( !filesize ) {
               errPtr = ZYPP_EXCPT_PTR( zypp::media::MediaException( zypp::str::Str() << "ExceededExpectedSize Error for URL: " << reqUrl << " " << reason ) );
@@ -440,7 +441,7 @@ namespace zyppng {
       return expected<zypp::media::AuthData>::success(*userAuth);
     } catch ( const zypp::Exception &e ) {
       ZYPP_CAUGHT(e);
-      return expected<zypp::media::AuthData>::error( std::current_exception() );
+      return expected<zypp::media::AuthData>::error( ZYPP_FWD_CURRENT_EXCPT() );
     }
   }
 
@@ -671,10 +672,11 @@ namespace zyppng {
         const auto cacheHit    = msg.value( ProvideFinishedMsgFields::CacheHit ).asBool();
         const auto &wConf      = queue.workerConfig();
 
+        const bool checkExistsOnly  = _initialSpec.checkExistsOnly();
         const bool doesDownload     = wConf.worker_type() == ProvideQueue::Config::Downloading;
         const bool fileNeedsCleanup = doesDownload || ( wConf.worker_type() == ProvideQueue::Config::CPUBound && wConf.cfg_flags() & ProvideQueue::Config::FileArtifacts );
 
-        if ( doesDownload ) {
+        if ( doesDownload && !checkExistsOnly ) {
 
           resFile = provider().addToFileCache ( locFilename );
           if ( !resFile ) {
@@ -695,7 +697,7 @@ namespace zyppng {
 
         } else {
           resFile = zypp::ManagedFile( zypp::filesystem::Pathname(locFilename) );
-          if ( fileNeedsCleanup )
+          if ( fileNeedsCleanup && !checkExistsOnly )
             resFile->setDispose( zypp::filesystem::unlink );
           else
             resFile->resetDispose();
