@@ -14,7 +14,9 @@
 
 #include <string>
 #include <list>
+#include <utility>
 
+#include <zypp/Globals.h>
 #include <zypp/Date.h>
 
 ///////////////////////////////////////////////////////////////////
@@ -32,9 +34,9 @@ namespace zypp
   public:
     /** Default ctor */
     ChangelogEntry( const Date & d,
-                    const std::string & a,
-                    const std::string & t )
-    : _date( d ), _author( a ), _text( t )
+                    std::string  a,
+                    std::string  t )
+    : _date( d ), _author(std::move( a )), _text(std::move( t ))
     {};
     /** Dtor */
     ~ChangelogEntry()
@@ -50,10 +52,10 @@ namespace zypp
   };
 
   /** List of ChangelogEntry. */
-  typedef std::list<ChangelogEntry> Changelog;
+  using Changelog = std::list<ChangelogEntry>;
 
   /** \relates ChangelogEntry */
-  std::ostream & operator<<( std::ostream & out, const ChangelogEntry & obj );
+  std::ostream & operator<<( std::ostream & out, const ChangelogEntry & obj ) ZYPP_API;
 
   ///////////////////////////////////////////////////////////////////
 } // namespace zypp
