@@ -51,7 +51,7 @@ namespace zypp
     DefaultIntegral<bool,false> read;
   };
 
-  typedef shared_ptr<FetcherIndex> FetcherIndex_Ptr;
+  using FetcherIndex_Ptr = shared_ptr<FetcherIndex>;
 
   /** std::set ordering (less semantic) */
   struct SameFetcherIndex
@@ -90,11 +90,12 @@ namespace zypp
     };
     ZYPP_DECLARE_FLAGS(Flags, Flag);
 
+    FetcherJob(const FetcherJob &) = default;
+    FetcherJob(FetcherJob &&) = default;
+    FetcherJob &operator=(const FetcherJob &) = default;
+    FetcherJob &operator=(FetcherJob &&) = default;
 
-    FetcherJob( const OnMediaLocation &loc )
-      : location(loc)
-      , flags(None)
-    {
+    FetcherJob(const OnMediaLocation &loc) : location(loc), flags(None) {
       //MIL << location << endl;
     }
 
@@ -110,7 +111,7 @@ namespace zypp
   };
 
   ZYPP_DECLARE_OPERATORS_FOR_FLAGS(FetcherJob::Flags);
-  typedef shared_ptr<FetcherJob> FetcherJob_Ptr;
+  using FetcherJob_Ptr = shared_ptr<FetcherJob>;
 
   std::ostream & operator<<( std::ostream & str, const FetcherJob_Ptr & obj )
   {
@@ -129,8 +130,22 @@ namespace zypp
   public:
     Impl();
 
+    Impl(const Impl &) = default;
+    Impl(Impl &&) = delete;
+    Impl &operator=(const Impl &) = delete;
+    Impl &operator=(Impl &&) = delete;
+
     ~Impl() {}
 
+    struct CacheInfo{
+      zypp::Pathname _pathName;
+      Fetcher::CacheOptions _options = Fetcher::Default;
+
+      friend bool operator<( const CacheInfo &a, const CacheInfo & b) {
+        return a._pathName < b._pathName;
+      }
+    };
+
     void setOptions( Fetcher::Options options );
     Fetcher::Options options() const;
 
@@ -141,7 +156,7 @@ namespace zypp
 
     void enqueue( const OnMediaLocation &resource, const FileChecker &checker = FileChecker()  );
     void enqueueDigested( const OnMediaLocation &resource, const FileChecker &checker = FileChecker() );
-    void addCachePath( const Pathname &cache_dir );
+    void addCachePath( const Pathname &cache_dir, Fetcher::CacheOptions options );
     void reset();
     void setMediaSetAccess ( MediaSetAccess &media );
     void start( const Pathname &dest_dir,
@@ -190,7 +205,7 @@ namespace zypp
        * the cache (matching checksum is mandatory). Returns the
        * location of the cached file or an empty \ref Pathname.
        */
-      Pathname locateInCache( const OnMediaLocation & resource_r, const Pathname & destDir_r );
+      ManagedFile locateInCache( const OnMediaLocation & resource_r, const Pathname & destDir_r );
       /**
        * Validates the provided file against its checkers.
        * \throws Exception
@@ -223,7 +238,7 @@ namespace zypp
 
     std::list<FetcherJob_Ptr>   _resources;
     std::set<FetcherIndex_Ptr,SameFetcherIndex> _indexes;
-    std::set<Pathname> _caches;
+    std::set<CacheInfo> _caches;
     // checksums read from the indexes
     std::map<std::string, CheckSum> _checksums;
     // cache of dir contents
@@ -321,7 +336,7 @@ namespace zypp
     _mediaSetAccess = &media;
   }
 
-  void Fetcher::Impl::addCachePath( const Pathname &cache_dir )
+  void Fetcher::Impl::addCachePath( const Pathname &cache_dir, Fetcher::CacheOptions options )
   {
     PathInfo info(cache_dir);
     if ( info.isExist() )
@@ -329,7 +344,7 @@ namespace zypp
       if ( info.isDir() )
       {
         DBG << "Adding fetcher cache: '" << cache_dir << "'." << endl;
-        _caches.insert(cache_dir);
+        _caches.insert( { cache_dir, options } );
       }
       else
       {
@@ -344,34 +359,31 @@ namespace zypp
 
   }
 
-  Pathname Fetcher::Impl::locateInCache( const OnMediaLocation & resource_r, const Pathname & destDir_r )
+  ManagedFile Fetcher::Impl::locateInCache( const OnMediaLocation & resource_r, const Pathname & destDir_r )
   {
-    Pathname ret;
     // No checksum - no match
     if ( resource_r.checksum().empty() )
-      return ret;
+      return {};
 
     // first check in the destination directory
-    Pathname cacheLocation = destDir_r / resource_r.filename();
-    if ( PathInfo(cacheLocation).isExist() && is_checksum( cacheLocation, resource_r.checksum() ) )
-    {
-      swap( ret, cacheLocation );
-      return ret;
+    ManagedFile cacheLocation(destDir_r / resource_r.filename());
+    if ( PathInfo(cacheLocation).isExist() && is_checksum( cacheLocation, resource_r.checksum() ) ) {
+      return cacheLocation;
     }
 
     MIL << "start fetcher with " << _caches.size() << " cache directories." << endl;
-    for( const Pathname & cacheDir : _caches )
-    {
-      cacheLocation = cacheDir / resource_r.filename();
+    for( const CacheInfo & cacheInfo : _caches ) {
+      cacheLocation = ManagedFile(cacheInfo._pathName / resource_r.filename());
       if ( PathInfo(cacheLocation).isExist() && is_checksum( cacheLocation, resource_r.checksum() ) )
       {
-        MIL << "file " << resource_r.filename() << " found in cache " << cacheDir << endl;
-        swap( ret, cacheLocation );
-        return ret;
+        MIL << "file " << resource_r.filename() << " found in cache " << cacheInfo._pathName << endl;
+        if ( cacheInfo._options & Fetcher::CleanFiles )
+          cacheLocation.setDispose( filesystem::unlink );
+        return cacheLocation;
       }
     }
 
-    return ret;
+    return {};
   }
 
   void Fetcher::Impl::validate( const Pathname & localfile_r, const std::list<FileChecker> & checkers_r )
@@ -527,7 +539,9 @@ namespace zypp
       scoped_ptr<MediaSetAccess::ReleaseFileGuard> releaseFileGuard; // will take care provided files get released
 
       // get cached file (by checksum) or provide from media
-      Pathname tmpFile = locateInCache( resource, destDir_r );
+      ManagedFile managedTmpFile = locateInCache( resource, destDir_r );
+
+      Pathname tmpFile = managedTmpFile;
       if ( tmpFile.empty() )
       {
         MIL << "Not found in cache, retrieving..." << endl;
@@ -652,7 +666,7 @@ namespace zypp
     SignatureFileChecker sigchecker;
 
     // build the name of the index and the signature
-    OnMediaLocation idxloc(resource);
+    const OnMediaLocation& idxloc(resource);
     OnMediaLocation sigloc(resource);
     OnMediaLocation keyloc(resource);
 
@@ -892,7 +906,12 @@ namespace zypp
 
   void Fetcher::addCachePath( const Pathname &cache_dir )
   {
-    _pimpl->addCachePath(cache_dir);
+    _pimpl->addCachePath(cache_dir, Fetcher::Default);
+  }
+
+  void Fetcher::addCachePath(const Pathname &cache_dir, CacheOptions options)
+  {
+    _pimpl->addCachePath(cache_dir, options);
   }
 
   void Fetcher::reset()
