@@ -23,9 +23,11 @@
 #include <zypp/Callback.h>
 #include <zypp/base/PtrTypes.h>
 #include <zypp/Locale.h>
-#include <zypp/PublicKey.h>
 #include <zypp/KeyRingContexts.h>
 
+#include <zypp-common/PublicKey.h>
+#include <zypp-common/KeyRingException.h>
+
 ///////////////////////////////////////////////////////////////////
 namespace zypp
 { /////////////////////////////////////////////////////////////////
@@ -157,25 +159,6 @@ namespace zypp
     {}
   };
 
-  class ZYPP_API KeyRingException : public Exception
-   {
-     public:
-       /** Ctor taking message.
-      * Use \ref ZYPP_THROW to throw exceptions.
-        */
-       KeyRingException()
-       : Exception( "Bad Key Exception" )
-       {}
-       /** Ctor taking message.
-        * Use \ref ZYPP_THROW to throw exceptions.
-        */
-       KeyRingException( const std::string & msg_r )
-       : Exception( msg_r )
-       {}
-       /** Dtor. */
-       ~KeyRingException() throw() override {};
-   };
-
   ///////////////////////////////////////////////////////////////////
   //
   //	CLASS NAME : KeyRing
