@@ -60,6 +60,14 @@ namespace zypp
     std::string		_details;
     SolutionActionList	_actions;
 
+    std::set<PoolItem> collectActionItems() const
+    {
+      std::set<PoolItem> ret;
+      for ( const auto & aptr : _actions )
+        ret.insert( aptr->item() );
+      return ret;
+    }
+
     template <typename Predicate>
     bool allActionsMatch( Predicate && predicate ) const
     {
@@ -108,8 +116,8 @@ namespace zypp
   void ProblemSolution::setDescription( std::string description )
   { _pimpl->_description = std::move(description); }
 
-  void ProblemSolution::setDetails( std::string details )
-  { _pimpl->_details += "\n"; _pimpl->_details += std::move(details); }
+  void ProblemSolution::setDetails( const std::string& details )
+  { _pimpl->_details += "\n"; _pimpl->_details += details; }
 
   void ProblemSolution::pushDescriptionDetail( std::string description, bool front )
   {
@@ -129,13 +137,12 @@ namespace zypp
     if ( front )
     { _pimpl->_details.swap( description ); }
     _pimpl->_details += "\n";
-    _pimpl->_details += std::move(description);
+    _pimpl->_details += description;
   }
 
-  void ProblemSolution::addAction( solver::detail::SolutionAction_Ptr action )
+  void ProblemSolution::addAction( const solver::detail::SolutionAction_Ptr& action )
   { _pimpl->_actions.push_back( action ); }
 
-
   bool ProblemSolution::skipsPatchesOnly() const
   {
     return _pimpl->allActionsMatch( []( const SolutionAction_Ptr & aptr ) -> bool {
@@ -143,6 +150,13 @@ namespace zypp
     } );
   }
 
+  std::optional<std::set<PoolItem>> ProblemSolution::getIfSkipsPatchesOnly() const
+  {
+    if ( not skipsPatchesOnly() )
+      return std::nullopt;
+    return _pimpl->collectActionItems();
+  }
+
 
   std::ostream & operator<<( std::ostream & os, const ProblemSolution & obj )
   {
