@@ -10,6 +10,7 @@
  *
 */
 #include <iostream>
+#include <utility>
 #include <zypp/base/LogTools.h>
 #include <zypp/base/StrMatcher.h>
 
@@ -33,7 +34,7 @@ namespace zypp
   {
     void fillList( std::list<std::string> & ret_r, sat::Solvable solv_r, sat::SolvAttr attr_r )
     {
-      sat::LookupAttr query( attr_r, solv_r );
+      sat::LookupAttr query( std::move(attr_r), solv_r );
       for_( it, query.begin(), query.end() )
       {
         ret_r.push_back( it.asString() );
@@ -171,7 +172,7 @@ namespace zypp
       if ( it->repository() == repository() )
       {
         // Got the package now try to get the provided 'flavor(...)'
-        Capabilities provides( it->provides() );
+        Capabilities provides( it->dep_provides() );
         for_( cap, provides.begin(), provides.end() )
         {
           std::string capstr( cap->asString() );
