@@ -13,8 +13,9 @@
 #define ZYPP_RESPOOL_H
 
 #include <iosfwd>
+#include <utility>
 
-#include <zypp/APIConfig.h>
+#include <zypp-core/Globals.h>
 #include <zypp/base/Iterator.h>
 
 #include <zypp/pool/PoolTraits.h>
@@ -57,16 +58,16 @@ namespace zypp
    *
    * \include n_ResPool_nomorenameiter
   */
-  class ResPool
+  class ZYPP_API ResPool
   {
     friend std::ostream & operator<<( std::ostream & str, const ResPool & obj );
 
     public:
       /** \ref PoolItem */
-      typedef PoolItem				         value_type;
-      typedef pool::PoolTraits::size_type		 size_type;
-      typedef pool::PoolTraits::const_iterator	         const_iterator;
-      typedef pool::PoolTraits::repository_iterator      repository_iterator;
+      using value_type = PoolItem;
+      using size_type = pool::PoolTraits::size_type;
+      using const_iterator = pool::PoolTraits::const_iterator;
+      using repository_iterator = pool::PoolTraits::repository_iterator;
 
     public:
       /** Singleton ctor. */
@@ -160,8 +161,8 @@ namespace zypp
     public:
       /** \name Iterate over all PoolItems of a certain name and kind. */
       //@{
-      typedef pool::ByIdent                       ByIdent;
-      typedef pool::PoolTraits::byIdent_iterator  byIdent_iterator;
+      using ByIdent = pool::ByIdent;
+      using byIdent_iterator = pool::PoolTraits::byIdent_iterator;
 
       byIdent_iterator byIdentBegin( const ByIdent & ident_r ) const
       {
@@ -170,10 +171,10 @@ namespace zypp
       }
 
       byIdent_iterator byIdentBegin( ResKind kind_r, IdString name_r ) const
-      { return byIdentBegin( ByIdent(kind_r,name_r) ); }
+      { return byIdentBegin( ByIdent(std::move(kind_r),name_r) ); }
 
       byIdent_iterator byIdentBegin( ResKind kind_r, const C_Str & name_r ) const
-      { return byIdentBegin( ByIdent(kind_r,name_r) ); }
+      { return byIdentBegin( ByIdent(std::move(kind_r),name_r) ); }
 
       template<class TRes>
       byIdent_iterator byIdentBegin( IdString name_r ) const
@@ -201,10 +202,10 @@ namespace zypp
       }
 
       byIdent_iterator byIdentEnd( ResKind kind_r, IdString name_r ) const
-      { return byIdentEnd( ByIdent(kind_r,name_r) ); }
+      { return byIdentEnd( ByIdent(std::move(kind_r),name_r) ); }
 
       byIdent_iterator byIdentEnd( ResKind kind_r, const C_Str & name_r ) const
-      { return byIdentEnd( ByIdent(kind_r,name_r) ); }
+      { return byIdentEnd( ByIdent(std::move(kind_r),name_r) ); }
 
       template<class TRes>
       byIdent_iterator byIdentEnd( IdString name_r ) const
@@ -228,10 +229,10 @@ namespace zypp
       Iterable<byIdent_iterator> byIdent( const ByIdent & ident_r ) const
       { return makeIterable( byIdentBegin( ident_r ), byIdentEnd( ident_r ) ); }
 
-      Iterable<byIdent_iterator> byIdent( ResKind kind_r, IdString name_r ) const
+      Iterable<byIdent_iterator> byIdent( const ResKind& kind_r, IdString name_r ) const
       { return makeIterable( byIdentBegin( kind_r, name_r ), byIdentEnd(  kind_r, name_r ) ); }
 
-      Iterable<byIdent_iterator> byIdent( ResKind kind_r, const C_Str & name_r ) const
+      Iterable<byIdent_iterator> byIdent( const ResKind& kind_r, const C_Str & name_r ) const
       { return makeIterable( byIdentBegin(  kind_r, name_r ), byIdentEnd(  kind_r, name_r ) ); }
 
       template<class TRes>
@@ -255,8 +256,8 @@ namespace zypp
     public:
       /** \name Iterate over all ResObjects of a certain kind. */
       //@{
-      typedef filter::ByKind ByKind;
-      typedef filter_iterator<ByKind,const_iterator> byKind_iterator;
+      using ByKind = filter::ByKind;
+      using byKind_iterator = filter_iterator<ByKind, const_iterator>;
 
       byKind_iterator byKindBegin( const ResKind & kind_r ) const
       { return make_filter_begin( ByKind(kind_r), *this ); }
@@ -283,8 +284,8 @@ namespace zypp
     public:
       /** \name Iterate over all ResObjects with a certain name (all kinds). */
       //@{
-      typedef zypp::resfilter::ByName ByName;
-      typedef filter_iterator<ByName,const_iterator> byName_iterator;
+      using ByName = zypp::resfilter::ByName;
+      using byName_iterator = filter_iterator<ByName, const_iterator>;
 
       byName_iterator byNameBegin( const std::string & name_r ) const
       { return make_filter_begin( ByName(name_r), *this ); }
@@ -315,7 +316,7 @@ namespace zypp
       public:
         ~EstablishedStates();
         /** Map holding pseudo installed items where current and established status differ. */
-        typedef std::map<PoolItem,ResStatus::ValidateValue> ChangedPseudoInstalled;
+        using ChangedPseudoInstalled = std::map<PoolItem, ResStatus::ValidateValue>;
         /** Return all pseudo installed items whose current state differs from the established one */
         ChangedPseudoInstalled changedPseudoInstalled() const;
       private:
@@ -325,7 +326,7 @@ namespace zypp
         friend class pool::PoolImpl;
         /** Factory: \ref ResPool::establishedStates */
         EstablishedStates( shared_ptr<Impl> pimpl_r )
-        : _pimpl { pimpl_r }
+        : _pimpl { std::move(pimpl_r) }
         {}
       };
       ///////////////////////////////////////////////////////////////////
@@ -338,7 +339,7 @@ namespace zypp
       EstablishedStates establishedStates() const;
 
       /** Map holding pseudo installed items where current and established status differ. */
-      typedef EstablishedStates::ChangedPseudoInstalled ChangedPseudoInstalled;
+      using ChangedPseudoInstalled = EstablishedStates::ChangedPseudoInstalled;
 
       /** Return all pseudo installed items whose current state differs from their initial one.
        * E.g. a Patch may become SATISFIED by updating the packages it refers to.
@@ -435,8 +436,8 @@ namespace zypp
        * These queries are re-evaluated when adding new repos to the pool.
        */
       //@{
-      typedef pool::PoolTraits::HardLockQueries           HardLockQueries;
-      typedef pool::PoolTraits::hardLockQueries_iterator  hardLockQueries_iterator;
+      using HardLockQueries = pool::PoolTraits::HardLockQueries;
+      using hardLockQueries_iterator = pool::PoolTraits::hardLockQueries_iterator;
 
       bool hardLockQueriesEmpty() const;
       size_type hardLockQueriesSize() const;
@@ -471,7 +472,7 @@ namespace zypp
   ///////////////////////////////////////////////////////////////////
 
   /** \relates ResPool Stream output */
-  std::ostream & operator<<( std::ostream & str, const ResPool & obj );
+  std::ostream & operator<<( std::ostream & str, const ResPool & obj ) ZYPP_API;
 
   /////////////////////////////////////////////////////////////////
 } // namespace zypp
