@@ -25,7 +25,7 @@ namespace zypp
 
     /** Those are denoted to be installed, if the
      *  solver verifies them as being satisfied. */
-    inline bool isPseudoInstalled( ResKind kind_r )
+    inline bool isPseudoInstalled( const ResKind& kind_r )
     { return( kind_r == ResKind::patch ); }
 
     /////////////////////////////////////////////////////////////////
@@ -78,11 +78,11 @@ namespace zypp
   template<typename TRes>
     struct ResTraits
     {
-      typedef ResKind                   KindType;
-      typedef intrusive_ptr<TRes>       PtrType;
-      typedef intrusive_ptr<const TRes> constPtrType;
+      using KindType = ResKind;
+      using PtrType = intrusive_ptr<TRes>;
+      using constPtrType = intrusive_ptr<const TRes>;
 
-      static const ResKind              kind;	///< Defined in ResKind.cc
+      static const ResKind              kind ZYPP_API;	///< Defined in ResKind.cc
 
       /** Those are denoted to be installed, if the
        *  solver verifies them as being satisfied. */
@@ -90,12 +90,12 @@ namespace zypp
     };
 
     // Defined in ResKind.cc
-    template<> const ResKind ResTraits<Package>::kind;
-    template<> const ResKind ResTraits<Patch>::kind;
-    template<> const ResKind ResTraits<Pattern>::kind;
-    template<> const ResKind ResTraits<Product>::kind;
-    template<> const ResKind ResTraits<SrcPackage>::kind;
-    template<> const ResKind ResTraits<Application>::kind;
+    template<> const ResKind ResTraits<Package>::kind ZYPP_API;
+    template<> const ResKind ResTraits<Patch>::kind ZYPP_API;
+    template<> const ResKind ResTraits<Pattern>::kind ZYPP_API;
+    template<> const ResKind ResTraits<Product>::kind ZYPP_API;
+    template<> const ResKind ResTraits<SrcPackage>::kind ZYPP_API;
+    template<> const ResKind ResTraits<Application>::kind ZYPP_API;
 
   /** ResTraits specialisation for Resolvable.
    * Resolvable is common base and has no Kind value.
@@ -103,9 +103,9 @@ namespace zypp
   template<>
     struct ResTraits<Resolvable>
     {
-      typedef ResKind                         KindType;
-      typedef intrusive_ptr<Resolvable>       PtrType;
-      typedef intrusive_ptr<const Resolvable> constPtrType;
+      using KindType = ResKind;
+      using PtrType = intrusive_ptr<Resolvable>;
+      using constPtrType = intrusive_ptr<const Resolvable>;
     };
 
   /** ResTraits specialisation for ResObject.
@@ -114,9 +114,9 @@ namespace zypp
   template<>
     struct ResTraits<ResObject>
     {
-      typedef ResKind                        KindType;
-      typedef intrusive_ptr<ResObject>       PtrType;
-      typedef intrusive_ptr<const ResObject> constPtrType;
+      using KindType = ResKind;
+      using PtrType = intrusive_ptr<ResObject>;
+      using constPtrType = intrusive_ptr<const ResObject>;
     };
 
   /** Convenient access to well known ResKinds.
