@@ -42,10 +42,10 @@ namespace zypp
     {
       for ( const ProblemSolution_Ptr & solution : solutions_r )
       {
-	if ( solution->description()	== solution_r->description()
-	  && solution->details()	== solution_r->details()
-	  && solution->actions().size()	== solution_r->actions().size() )
-	  return true;
+        if ( solution->description()	== solution_r->description()
+          && solution->details()	== solution_r->details()
+          && solution->actions().size()	== solution_r->actions().size() )
+          return true;
       }
       return false;
     }
@@ -127,7 +127,7 @@ namespace zypp
   void ResolverProblem::setDetails( std::string details )
   { _pimpl->_details = std::move(details); }
 
-  void ResolverProblem::addSolution( ProblemSolution_Ptr solution, bool inFront )
+  void ResolverProblem::addSolution( const ProblemSolution_Ptr& solution, bool inFront )
   {
     if ( ! solutionInList( _pimpl->_solutions, solution ) )	// bsc#985674: filter duplicate solutions
     {
