@@ -61,14 +61,14 @@ namespace zypp
      * \endcode
      * \see Reader
     */
-    class Writer
+    class ZYPP_API Writer
     {
-      typedef std::set<ResObject::constPtr> StorageT;
+      using StorageT = std::set<ResObject::constPtr>;
     public:
-      typedef StorageT::value_type     value_type;
-      typedef StorageT::size_type      size_type;
-      typedef StorageT::iterator       iterator;
-      typedef StorageT::const_iterator const_iterator;
+      using value_type = StorageT::value_type;
+      using size_type = StorageT::size_type;
+      using iterator = StorageT::iterator;
+      using const_iterator = StorageT::const_iterator;
 
     public:
       /** Default Ctor. */
@@ -168,20 +168,20 @@ namespace zypp
     /** Retrieve \ref ResObject data serialized by \ref Writer.
      * \see Writer
     */
-    class Reader
+    class ZYPP_API Reader
     {
     public:
       /** Restored \ref ResObject data. */
       class Entry;
 
     private:
-      typedef std::list<Entry> StorageT;
+      using StorageT = std::list<Entry>;
 
     public:
-      typedef StorageT::value_type     value_type;
-      typedef StorageT::size_type      size_type;
-      typedef StorageT::iterator       iterator;
-      typedef StorageT::const_iterator const_iterator;
+      using value_type = StorageT::value_type;
+      using size_type = StorageT::size_type;
+      using iterator = StorageT::iterator;
+      using const_iterator = StorageT::const_iterator;
 
     public:
       /** Default Ctor. */
@@ -240,7 +240,7 @@ namespace zypp
     //	CLASS NAME : Reader::Entry
     //
     /** Restored \ref ResObject data. */
-    class Reader::Entry
+    class ZYPP_API Reader::Entry
     {
     public:
       Entry();
