@@ -20,7 +20,7 @@
 #include <zypp/PathInfo.h>
 #include <zypp/Vendor.h>
 
-#include <zypp/APIConfig.h>	// LEGACY macros
+#include <zypp-core/Globals.h>	// LEGACY macros
 
 ///////////////////////////////////////////////////////////////////
 namespace zypp {
@@ -57,7 +57,7 @@ namespace zypp {
  *
  * \see \ref pg_zypp-solv-vendorchange
 */
-class VendorAttr
+class ZYPP_API VendorAttr
 {
     friend std::ostream & operator<<( std::ostream & str, const VendorAttr & obj );
 
@@ -81,26 +81,23 @@ class VendorAttr
     /** Dtor */
     ~VendorAttr();
 
+    VendorAttr(const VendorAttr &) = default;
+    VendorAttr(VendorAttr &&) noexcept = default;
+    VendorAttr &operator=(const VendorAttr &) = default;
+    VendorAttr &operator=(VendorAttr &&) noexcept = default;
+
     /**
      * Adding new equivalent vendors described in a directory
      **/
     bool addVendorDirectory( const Pathname & dirname_r );
-#if LEGACY(1722)
-    /** \deprecated This is NOT a CONST operation. */
-    bool addVendorDirectory( const Pathname & dirname_r ) const ZYPP_DEPRECATED;
-#endif
 
     /**
      * Adding new equivalent vendors described in a file
      **/
     bool addVendorFile( const Pathname & filename_r );
-#if LEGACY(1722)
-    /** \deprecated This is NOT a CONST operation. */
-    bool addVendorFile( const Pathname & filename_r ) const ZYPP_DEPRECATED;
-#endif
 
     /** Preferred type to pass equivalent vendor strings. */
-    typedef std::vector<std::string> VendorList;
+    using VendorList = std::vector<std::string>;
 
     /**
      * Adding new equivalent vendor strings container.
@@ -161,17 +158,11 @@ class VendorAttr
     class Impl;                 ///< Implementation class.
     RWCOW_pointer<Impl> _pimpl; ///< Pointer to implementation.
 
-#if LEGACY(1722)
-    /** \deprecated */
-    void _addVendorList( std::vector<std::string> & list_r ) const ZYPP_DEPRECATED;
-    /** \deprecated */
-    void _addVendorList( std::vector<IdString> && list_r );
-#endif
     void _addVendorList( VendorList && list_r );
 };
 
 /** \relates VendorAttr Stream output */
-std::ostream & operator<<( std::ostream & str, const VendorAttr & obj );
+std::ostream & operator<<( std::ostream & str, const VendorAttr & obj ) ZYPP_API;
 
 ///////////////////////////////////////////////////////////////////
 }; // namespace zypp
