@@ -75,6 +75,10 @@ namespace zypp
       /** Print some detail about the current libzypp version.*/
       std::ostream & about( std::ostream & str ) const;
 
+    public:
+      /** The number of seconds to wait for the zypp lock to become available. */
+      long lockTimeout() const;
+
     public:
 
       /** The target root directory.
