@@ -34,6 +34,7 @@ namespace zypp
     public:
       Pathname			_root;
       FalseBool			_attemptToModify;
+      FalseBool                 _singleTransactionMode;
       sat::Transaction          _transaction;
       TransactionStepList       _transactionStepList;
       UpdateNotifications	_updateMessages;
@@ -74,6 +75,12 @@ namespace zypp
   void ZYppCommitResult::attemptToModify( bool yesno_r )
   { _pimpl->_attemptToModify = yesno_r; }
 
+  bool ZYppCommitResult::singleTransactionMode() const
+  { return _pimpl->_singleTransactionMode; }
+
+  void ZYppCommitResult::setSingleTransactionMode( bool yesno_r )
+  { _pimpl->_singleTransactionMode = yesno_r; }
+
   const sat::Transaction & ZYppCommitResult::transaction() const
   { return _pimpl->_transaction; }
 
@@ -102,9 +109,9 @@ namespace zypp
       ++result[0];
       switch ( it->stepStage() )
       {
-	case sat::Transaction::STEP_DONE :	++result[1]; break;
-	case sat::Transaction::STEP_ERROR :	++result[2]; break;
-	case sat::Transaction::STEP_TODO :	++result[3]; break;
+        case sat::Transaction::STEP_DONE :	++result[1]; break;
+        case sat::Transaction::STEP_ERROR :	++result[2]; break;
+        case sat::Transaction::STEP_TODO :	++result[3]; break;
       }
     }
     str << "CommitResult "
