@@ -28,7 +28,7 @@ namespace zypp {
     class MediaCD : public MediaHandler {
 
       private:
-        typedef std::list<MediaSource> DeviceList;
+        using DeviceList = std::list<MediaSource>;
         /** list of devices to try to mount */
         mutable DeviceList _devices;
 
@@ -39,36 +39,36 @@ namespace zypp {
         static bool openTray( const std::string & device_r );
         static bool closeTray( const std::string & device_r );
 
-	DeviceList  detectDevices(bool supportingDVD) const;
+        DeviceList  detectDevices(bool supportingDVD) const;
 
       protected:
 
-	virtual void attachTo (bool next = false) override;
-        virtual void releaseFrom( const std::string & ejectDev ) override;
-	virtual void getFile(const Pathname & filename, const ByteCount &expectedFileSize_r ) const override;
-	virtual void getDir( const Pathname & dirname, bool recurse_r ) const override;
-        virtual void getDirInfo( std::list<std::string> & retlist,
+        void attachTo (bool next = false) override;
+        void releaseFrom( const std::string & ejectDev ) override;
+        void getFile(const OnMediaLocation & file) const override;
+        void getDir( const Pathname & dirname, bool recurse_r ) const override;
+        void getDirInfo( std::list<std::string> & retlist,
                                  const Pathname & dirname, bool dots = true ) const override;
-        virtual void getDirInfo( filesystem::DirContent & retlist,
+        void getDirInfo( filesystem::DirContent & retlist,
                                  const Pathname & dirname, bool dots = true ) const override;
-        virtual bool getDoesFileExist( const Pathname & filename ) const override;
+        bool getDoesFileExist( const Pathname & filename ) const override;
 
-        virtual void forceEject(const std::string & ejectDev) override;
+        void forceEject(const std::string & ejectDev) override;
 
-        virtual bool hasMoreDevices() override;
+        bool hasMoreDevices() override;
 
-        virtual void
+        void
         getDetectedDevices(std::vector<std::string> & devices,
                            unsigned int & index) const override;
 
       public:
 
         MediaCD( const Url &      url_r,
-		 const Pathname & attach_point_hint_r );
+                 const Pathname & attach_point_hint_r );
 
-        virtual ~MediaCD() override { try { release(); } catch(...) {} }
+        ~MediaCD() override { try { release(); } catch(...) {} }
 
-	virtual bool isAttached() const override;
+        bool isAttached() const override;
     };
 
 ///////////////////////////////////////////////////////////////////
