@@ -15,6 +15,7 @@
 #include <iosfwd>
 #include <vector>
 #include <string>
+#include <zypp/Globals.h>
 #include <zypp/Pathname.h>
 #include <zypp/base/PtrTypes.h>
 
@@ -38,7 +39,7 @@ namespace zypp
    * enabled by \ref setDebugOutputFile.\n
    * This data file can be used as datasource when passed to \ref check(const Pathname &, bool).
    */
-  class CheckAccessDeleted
+  class ZYPP_API CheckAccessDeleted
   {
 
     public:
@@ -62,9 +63,9 @@ namespace zypp
         std::string service() const;
       };
 
-      typedef size_t					size_type;
-      typedef ProcInfo					value_type;
-      typedef std::vector<ProcInfo>::const_iterator	const_iterator;
+      using size_type = size_t;
+      using value_type = ProcInfo;
+      using const_iterator = std::vector<ProcInfo>::const_iterator;
 
     public:
       /** Default ctor performs check immediately.
