@@ -36,6 +36,9 @@ namespace zypp
 
     void defaultLoadSystem( const Pathname & sysRoot_r, LoadSystemFlags flags_r )
     {
+      if ( not flags_r && geteuid() != 0 ) {
+        flags_r |= LS_NOREFRESH;
+      }
       MIL << str::form( "*** Load system at '%s' (%lx)", sysRoot_r.c_str(), (unsigned long)flags_r ) << endl;
 
       if ( ! PathInfo( sysRoot_r ).isDir() )
@@ -57,7 +60,7 @@ namespace zypp
         MIL << satpool.systemRepo() << endl;
       }
 
-      if ( 1 )
+      if ( not flags_r.testFlag( LS_NOREPOS ) )
       {
         RepoManager repoManager( sysRoot_r );
         RepoInfoList repos = repoManager.knownRepositories();
