@@ -15,7 +15,7 @@
 #include <zypp-media/ng/ProvideSpec>
 #include <zypp/ng/Context>
 #include <zypp/ng/repo/Downloader>
-#include <zypp/PublicKey.h>
+#include <zypp-common/PublicKey.h>
 #include <zypp/KeyRing.h>
 
 #include <zypp/ng/workflows/signaturecheckwf.h>
@@ -27,6 +27,10 @@
 #include <zypp/ng/workflows/contextfacade.h>
 #include <zypp/ng/workflows/mediafacade.h>
 
+#undef  ZYPP_BASE_LOGGER_LOGGROUP
+#define ZYPP_BASE_LOGGER_LOGGROUP "zypp::repomanager"
+
+
 namespace zyppng {
   namespace {
 
@@ -58,27 +62,29 @@ namespace zyppng {
         _destdir = _dlContext->destDir();
 
         auto providerRef = _dlContext->zyppContext()->provider();
-        return std::vector {
-           // fetch signature and keys
-            providerRef->provide( _media, _sigpath, ProvideFileSpec().setOptional( true ).setDownloadSize( zypp::ByteCount( 20, zypp::ByteCount::MB ) ) )
-             | and_then( ProvideType::copyResultToDest ( providerRef, _destdir / _sigpath ) ),
-            providerRef->provide( _media, _keypath, ProvideFileSpec().setOptional( true ).setDownloadSize( zypp::ByteCount( 20, zypp::ByteCount::MB ) ) )
-             | and_then( ProvideType::copyResultToDest ( providerRef, _destdir / _keypath ) ),
-           }
-          | join()
-          | [this]( std::vector<expected<zypp::ManagedFile>> &&res ) {
+          return provider()->provide( _media, _masterIndex, ProvideFileSpec().setDownloadSize( zypp::ByteCount( 20, zypp::ByteCount::MB ) ) )
+          | and_then( [this]( ProvideRes && masterres ) {
 
-             // remember downloaded files
-             std::for_each( res.begin (), res.end(),
-               [this]( expected<zypp::ManagedFile> &f){
-                 if (f.is_valid () ) {
-                   _dlContext->files().push_back( std::move(f.get()));
-                 }
-             });
+            return std::vector {
+              // fetch signature and keys
+              provider()->provide( _media, _sigpath, ProvideFileSpec().setOptional( true ).setDownloadSize( zypp::ByteCount( 20, zypp::ByteCount::MB ) ) )
+              | and_then( ProvideType::copyResultToDest ( provider(), _destdir / _sigpath ) ),
+              provider()->provide( _media, _keypath, ProvideFileSpec().setOptional( true ).setDownloadSize( zypp::ByteCount( 20, zypp::ByteCount::MB ) ) )
+              | and_then( ProvideType::copyResultToDest ( provider(), _destdir / _keypath ) ),
+            }
+            | join()
+            | [this,masterres=std::move(masterres)]( std::vector<expected<zypp::ManagedFile>> &&res ) {
+              // remember downloaded files
+              std::for_each( res.begin (), res.end(),
+                             [this]( expected<zypp::ManagedFile> &f){
+                               if (f.is_valid () ) {
+                                 _dlContext->files().push_back( std::move(f.get()));
+                               }
+                             });
+              return make_expected_success( std::move(masterres) );
+            };
 
-             // get the master index file
-             return provider()->provide( _media, _masterIndex, ProvideFileSpec().setDownloadSize( zypp::ByteCount( 20, zypp::ByteCount::MB ) ) );
-           }
+          } )
           // execute plugin verification if there is one
           | and_then( std::bind( &DownloadMasterIndexLogic::pluginVerification, this, std::placeholders::_1 ) )
 
@@ -132,7 +138,7 @@ namespace zyppng {
               try {
                 _dlContext->zyppContext()->keyRing()->importKey( zypp::PublicKey(keypathLocal), false );
               } catch (...) {
-                return makeReadyResult( expected<ProvideRes>::error( std::current_exception() ) );
+                return makeReadyResult( expected<ProvideRes>::error( ZYPP_FWD_CURRENT_EXCPT() ) );
               }
             }
 
@@ -222,7 +228,7 @@ namespace zyppng {
                    else
                      return expected<zypp::PublicKey>::error( std::make_exception_ptr (zypp::Exception("File does not provide key")));
                  }
-               | or_else ([ this, file = file, keyid = keyid, cacheFile ] ( auto && ) mutable -> MaybeAsyncRef<expected<zypp::PublicKey>> {
+               | or_else ([ this, file = file, keyid = keyid, cacheFile ] ( auto ) mutable -> MaybeAsyncRef<expected<zypp::PublicKey>> {
                    auto providerRef = _dlContext->zyppContext()->provider();
                    return providerRef->provide( _media, file, ProvideFileSpec().setOptional(true) )
                       | and_then( ProvideType::copyResultToDest( providerRef, _destdir / file ) )
@@ -233,7 +239,7 @@ namespace zyppng {
 
                           auto key = zypp::PublicKey::noThrow( _dlContext->files().back() );
                           if ( not key.fileProvidesKey( keyid ) ) {
-                            const auto &str = zypp::str::Str() << "Keyhint " << file << " does not contain a key with id " << keyid << ". Skipping it.";
+                            const std::string str = (zypp::str::Str() << "Keyhint " << file << " does not contain a key with id " << keyid << ". Skipping it.");
                             WAR << str << std::endl;
                             return makeReadyResult(expected<zypp::PublicKey>::error( std::make_exception_ptr( zypp::Exception(str)) ));
                           }
@@ -295,6 +301,24 @@ namespace zyppng {
       return SimpleExecutor<DownloadMasterIndexLogic, SyncOp<expected<repo::SyncDownloadContextRef>>>::run( std::move(dl), std::move(mediaHandle), std::move(masterIndex_r) );
     }
 
+    AsyncOpRef<expected<repo::AsyncDownloadContextRef>> RepoDownloaderWorkflow::downloadMasterIndex ( repo::AsyncDownloadContextRef dl, AsyncLazyMediaHandle mediaHandle, zypp::filesystem::Pathname masterIndex_r )
+    {
+      using namespace zyppng::operators;
+      return dl->zyppContext()->provider()->attachMediaIfNeeded( mediaHandle )
+      | and_then([ dl, mi = std::move(masterIndex_r) ]( ProvideMediaHandle handle ) mutable {
+        return downloadMasterIndex( std::move(dl), std::move(handle), std::move(mi) );
+      });
+    }
+
+    expected<repo::SyncDownloadContextRef> RepoDownloaderWorkflow::downloadMasterIndex ( repo::SyncDownloadContextRef dl, SyncLazyMediaHandle mediaHandle, zypp::filesystem::Pathname masterIndex_r )
+    {
+      using namespace zyppng::operators;
+      return dl->zyppContext()->provider()->attachMediaIfNeeded( mediaHandle )
+      | and_then([ dl, mi = std::move(masterIndex_r) ]( SyncMediaHandle handle ) mutable {
+        return downloadMasterIndex( std::move(dl), std::move(handle), std::move(mi) );
+      });
+    }
+
 
     namespace {
       template <class DlContextRefType, class MediaHandleType>
@@ -329,6 +353,22 @@ namespace zyppng {
        return statusImpl( dl, std::move(mediaHandle) );
     }
 
+    AsyncOpRef<expected<zypp::RepoStatus> > RepoDownloaderWorkflow::repoStatus( repo::AsyncDownloadContextRef dl, AsyncLazyMediaHandle mediaHandle ) {
+      using namespace zyppng::operators;
+      return dl->zyppContext()->provider()->attachMediaIfNeeded( mediaHandle )
+      | and_then([ dl ]( ProvideMediaHandle handle ) {
+        return repoStatus( dl, std::move(handle) );
+      });
+    }
+
+    expected<zypp::RepoStatus> RepoDownloaderWorkflow::repoStatus( repo::SyncDownloadContextRef dl, SyncLazyMediaHandle mediaHandle ) {
+      using namespace zyppng::operators;
+      return dl->zyppContext()->provider()->attachMediaIfNeeded( mediaHandle )
+      | and_then([ dl ]( SyncMediaHandle handle ) {
+        return repoStatus( dl, std::move(handle) );
+      });
+    }
+
 
     namespace {
       template <class DlContextRefType, class MediaHandleType>
@@ -361,4 +401,22 @@ namespace zyppng {
       return downloadImpl( dl, std::move(mediaHandle), std::move(progressObserver) );
     }
 
+    AsyncOpRef<expected<repo::AsyncDownloadContextRef> > RepoDownloaderWorkflow::download(repo::AsyncDownloadContextRef dl, AsyncLazyMediaHandle mediaHandle, ProgressObserverRef progressObserver)
+    {
+      using namespace zyppng::operators;
+      return dl->zyppContext()->provider()->attachMediaIfNeeded( mediaHandle )
+      | and_then([ dl, po = std::move(progressObserver) ]( ProvideMediaHandle handle ) mutable {
+        return downloadImpl( dl, std::move(handle), std::move(po) );
+      });
+    }
+
+    expected<repo::SyncDownloadContextRef> RepoDownloaderWorkflow::download(repo::SyncDownloadContextRef dl, SyncLazyMediaHandle mediaHandle, ProgressObserverRef progressObserver)
+    {
+      using namespace zyppng::operators;
+      return dl->zyppContext()->provider()->attachMediaIfNeeded( mediaHandle )
+      | and_then([ dl, po = std::move(progressObserver) ]( SyncMediaHandle handle ) mutable {
+        return downloadImpl( dl, std::move(handle), std::move(po) );
+      });
+    }
+
 }
