@@ -63,7 +63,7 @@ namespace zypp
   /// \see \ref HistoryLogData for how to access the individual data fields.
   ///
   ///////////////////////////////////////////////////////////////////
-  class HistoryLogReader
+  class ZYPP_API HistoryLogReader
   {
   public:
 
@@ -77,13 +77,13 @@ namespace zypp
     /** Callback type to consume a single history line split into fields.
      * The return value indicates whether to continue parsing.
      */
-    typedef function< bool( const HistoryLogData::Ptr & )> ProcessData;
+    using ProcessData = function<bool (const HistoryLogData::Ptr &)>;
 
     /** Ctor taking file to parse and data consumer callback.
      * As \a options_r argument pass \c HistoryLogReader::Options() to
      * use the default stettings, or an OR'ed combination of \ref OptionBits.
      */
-    HistoryLogReader( const Pathname & historyFile_r, const Options & options_r, const ProcessData & callback_r );
+    HistoryLogReader(Pathname historyFile_r, zypp::parser::HistoryLogReader::Options options_r, ProcessData callback_r );
 
     ~HistoryLogReader();
 
