@@ -49,7 +49,7 @@ namespace zypp
       {
         friend class ContentFileReader;
         public:
-          typedef std::map<std::string, CheckSum> FileChecksumMap;
+          using FileChecksumMap = std::map<std::string, CheckSum>;
 
           Pathname descrdir;
           Pathname datadir;
@@ -60,7 +60,7 @@ namespace zypp
 
         protected:
           /** Overload to realize std::ostream & operator\<\<. */
-          virtual std::ostream & dumpOn( std::ostream & str ) const;
+          std::ostream & dumpOn( std::ostream & str ) const override;
       };
       //////////////////////////////////////////////////////////////////
 
