@@ -16,7 +16,8 @@
 #include <zypp/base/Function.h>
 #include <zypp/base/Hash.h>
 #include <zypp/base/String.h>
-#include <zypp/base/DefaultIntegral.h>
+#include <utility>
+#include <zypp-core/base/DefaultIntegral>
 
 #include <zypp/parser/xml/Node.h>
 
@@ -61,14 +62,14 @@ namespace zypp
     {
     public:
       ParseDefConsumeRedirect();
-      ParseDefConsumeRedirect( const shared_ptr<ParseDefConsume> & target_r );
+      ParseDefConsumeRedirect( shared_ptr<ParseDefConsume> target_r );
       ParseDefConsumeRedirect( ParseDefConsume * allocatedTarget_r );
       ParseDefConsumeRedirect( ParseDefConsume & target_r );
 
-      virtual ~ParseDefConsumeRedirect();
+      ~ParseDefConsumeRedirect() override;
 
     public:
-      void setRedirect( const shared_ptr<ParseDefConsume> & target_r );
+      void setRedirect( shared_ptr<ParseDefConsume> target_r );
       void setRedirect( ParseDefConsume * allocatedTarget_r );
       void setRedirect( ParseDefConsume & target_r );
       void cancelRedirect();
@@ -76,12 +77,12 @@ namespace zypp
       shared_ptr<ParseDefConsume> getRedirect() const;
 
     public:
-      virtual void start( const Node & _node );
-      virtual void text ( const Node & _node );
-      virtual void cdata( const Node & _node );
-      virtual void done ( const Node & _node );
-      virtual void startSubnode( const Node & _node );
-      virtual void doneSubnode ( const Node & _node );
+      void start( const Node & _node ) override;
+      void text ( const Node & _node ) override;
+      void cdata( const Node & _node ) override;
+      void done ( const Node & _node ) override;
+      void startSubnode( const Node & _node ) override;
+      void doneSubnode ( const Node & _node ) override;
 
     private:
       shared_ptr<ParseDefConsume> _target;
@@ -97,19 +98,19 @@ namespace zypp
     class ParseDefConsumeCallback : public ParseDefConsume
     {
     public:
-      typedef function<void(const Node &)> Callback;
+      using Callback = function<void (const Node &)>;
 
       ParseDefConsumeCallback();
 
-      virtual ~ParseDefConsumeCallback();
+      ~ParseDefConsumeCallback() override;
 
     public:
-      virtual void start( const Node & node_r );
-      virtual void text( const Node & node_r );
-      virtual void cdata( const Node & node_r );
-      virtual void done( const Node & node_r );
-      virtual void startSubnode( const Node & node_r );
-      virtual void doneSubnode( const Node & node_r );
+      void start( const Node & node_r ) override;
+      void text( const Node & node_r ) override;
+      void cdata( const Node & node_r ) override;
+      void done( const Node & node_r ) override;
+      void startSubnode( const Node & node_r ) override;
+      void doneSubnode( const Node & node_r ) override;
 
     public:
       Callback _start;
@@ -127,7 +128,7 @@ namespace zypp
     { /////////////////////////////////////////////////////////////////
       template <class Tp> struct Assigner;
 
-      typedef shared_ptr<Assigner<void> > AssignerRef;
+      using AssignerRef = shared_ptr<Assigner<void>>;
 
       /** Common interface to all Assigner types. */
       template <>
@@ -149,7 +150,7 @@ namespace zypp
           : _value( &value_r )
         {}
 
-        virtual void assign( const char * text_r )
+        void assign( const char * text_r ) override
         { *_value = Tp( text_r ); }
 
         private:
@@ -221,13 +222,13 @@ namespace zypp
 
         /** Set pre notification callback. */
         void prenotify( function<void ( const Node & )> pre_r )
-        { _pre = pre_r; }
+        { _pre = std::move(pre_r); }
 
         /** Set post notification callback. */
         void postnotify( function<void ( const Node & )> post_r )
-        { _post = post_r; }
+        { _post = std::move(post_r); }
 
-        virtual void start( const xml::Node & node_r )
+        void start( const xml::Node & node_r ) override
         {
           if ( _pre )
             _pre( node_r );
@@ -237,13 +238,13 @@ namespace zypp
               assign( it->second, node_r.getAttribute( it->first.c_str() ).c_str() );
         }
 
-        virtual void text( const xml::Node & node_r )
+        void text( const xml::Node & node_r ) override
         {
           if ( ! _text.empty() )
             assign( _text, node_r.value().c_str() );
         }
 
-        virtual void done( const xml::Node & node_r )
+        void done( const xml::Node & node_r ) override
         {
           if ( _post )
             _post( node_r );
@@ -308,11 +309,11 @@ namespace zypp
 
         /** Set pre notification callback. */
         Builder & operator<<( function<void ( const Node & )> done_r )
-        { _ptr->prenotify( done_r ); return *this; }
+        { _ptr->prenotify( std::move(done_r) ); return *this; }
 
         /** Set post notification callback. */
         Builder & operator>>( function<void ( const Node & )> done_r )
-        { _ptr->postnotify( done_r ); return *this; }
+        { _ptr->postnotify( std::move(done_r) ); return *this; }
 
         /** Type conversion so this can be passed as node consumer to \ref ParseDef. */
         operator shared_ptr<ParseDefConsume> () const
@@ -330,9 +331,9 @@ namespace zypp
      * \relates parse_def_assign::Builder
      *
      * This function allows convenient contruction of a \ref parse_def_assign::Consumer
-     * to be passed as \ref Node conssumer to \ref ParseDef. Simply list each attributes
-     * name together with the variable it's value should be assigned to. If the attribute
-     * name is omitted, the nodes text value gets assigned.
+     * to be passed as \ref Node conssumer to \ref ParseDef. Simply list each attribute's
+     * name together with the variable its value should be assigned to. If the attribute
+     * name is omitted, the node's text value gets assigned.
      *
      * Target variables can be of any type tsupported by \ref Assigner.
      * Basically all types constructible from \c char*, or where a
