@@ -33,7 +33,7 @@ namespace zypp
      * gets all patches and deltas from them for a given
      * package.
      */
-    class DeltaCandidates
+    class ZYPP_API DeltaCandidates
     {
       friend std::ostream & operator<<( std::ostream & str, const DeltaCandidates & obj );
 
@@ -43,11 +43,16 @@ namespace zypp
 
     public:
       DeltaCandidates();
+
+      DeltaCandidates(const DeltaCandidates &) = default;
+      DeltaCandidates(DeltaCandidates &&) noexcept = default;
+      DeltaCandidates &operator=(const DeltaCandidates &) = default;
+      DeltaCandidates &operator=(DeltaCandidates &&) noexcept = default;
       /**
        * \short Creates a candidate calculator
        * \param repos Set of repositories providing patch and delta packages
        */
-      DeltaCandidates( const std::list<Repository> & repos, const std::string & pkgname = "" );
+      DeltaCandidates( std::list<Repository> repos, std::string pkgname = "" );
       /** Dtor */
       ~DeltaCandidates();
 
@@ -60,7 +65,7 @@ namespace zypp
     ///////////////////////////////////////////////////////////////////
 
     /** \relates DeltaCandidates Stream output */
-    std::ostream & operator<<( std::ostream & str, const DeltaCandidates & obj );
+    std::ostream & operator<<( std::ostream & str, const DeltaCandidates & obj ) ZYPP_API;
 
     ///////////////////////////////////////////////////////////////////
 
