@@ -30,10 +30,10 @@ namespace zypp
     /// \Note Requested sizes are filled up to the next multiple of eight.
     /// Libsolv bitmaps are not shrinkable.
     ///////////////////////////////////////////////////////////////////
-    class Map
+    class ZYPP_API Map
     {
     public:
-      typedef unsigned long size_type;
+      using size_type = unsigned long;
 
       /** Type to indicate the bitmap should match the current pools capacity. */
       struct PoolSizeType {};
@@ -117,7 +117,7 @@ namespace zypp
     { return str << obj.asString(); }
 
     /** \relates Map */
-    bool operator==( const Map & lhs, const Map & rhs );
+    bool operator==( const Map & lhs, const Map & rhs ) ZYPP_API;
 
     /** \relates Map */
     inline bool operator!=( const Map & lhs, const Map & rhs )
@@ -129,7 +129,7 @@ namespace zypp
   /** \relates Map Clone function for RWCOW_pointer */
   template<> sat::detail::CMap * rwcowClone<sat::detail::CMap>( const sat::detail::CMap * rhs );
 
-  typedef sat::Map Bitmap;
+  using Bitmap = sat::Map;
 
 } // namespace zypp
 ///////////////////////////////////////////////////////////////////
