@@ -30,6 +30,7 @@
 #include <list>
 #include <map>
 
+#include <zypp/Globals.h>
 #include <zypp/solver/Types.h>
 #include <zypp/base/SerialNumber.h>
 
@@ -60,7 +61,7 @@ namespace zypp
  * all the solver logic and problem handling goes here; or completely merge
  * both classes.
  */
-class Resolver : private base::NonCopyable
+class ZYPP_API_DEPTESTOMATIC Resolver : private base::NonCopyable
 {
   typedef std::multimap<PoolItem,ItemCapKind> ItemCapKindMap;
   private:
@@ -126,7 +127,7 @@ class Resolver : private base::NonCopyable
 
   public:
 
-    Resolver( const ResPool & pool );
+    Resolver( ResPool  pool );
     virtual ~Resolver();
 
     // ---------------------------------- I/O
@@ -163,8 +164,8 @@ class Resolver : private base::NonCopyable
     void addExtraConflict( const Capability & capability );
     void removeExtraConflict( const Capability & capability );
 
-    void removeQueueItem( SolverQueueItem_Ptr item );
-    void addQueueItem( SolverQueueItem_Ptr item );
+    void removeQueueItem( const SolverQueueItem_Ptr& item );
+    void addQueueItem( const SolverQueueItem_Ptr& item );
 
     CapabilitySet extraRequires() const		{ return _extra_requires; }
     CapabilitySet extraConflicts() const	{ return _extra_conflicts; }
@@ -197,6 +198,12 @@ class Resolver : private base::NonCopyable
     void setSolveSrcPackages( TriBool state_r )	{ _solveSrcPackages = indeterminate(state_r) ? false : bool(state_r); }
     //@}
 
+    void setRemoveOrphaned( bool yesno_r );
+    bool removeOrphaned() const;
+
+    void setRemoveUnneeded( bool yesno_r );
+    bool removeUnneeded() const;
+
     void setFocus( ResolverFocus focus_r );
     ResolverFocus focus() const;
 
