@@ -20,6 +20,7 @@
 #include <zypp/solver/detail/Testcase.h>
 #include <zypp/base/Logger.h>
 #include <zypp/base/LogControl.h>
+#include <utility>
 #include <zypp-core/base/GzStream>
 #include <zypp/base/String.h>
 #include <zypp/base/PtrTypes.h>
@@ -62,8 +63,8 @@ namespace zypp
         :dumpPath("/var/log/YaST2/solverTestcase")
       {}
 
-      Testcase::Testcase(const std::string & path)
-        :dumpPath(path)
+      Testcase::Testcase(std::string  path)
+        :dumpPath(std::move(path))
       {}
 
       Testcase::~Testcase()
@@ -196,14 +197,14 @@ namespace zypp
         const LocaleSet & requestedLocales( satpool.getRequestedLocales() );
 
         yOut << YAML::Key << "locales" << YAML::Value << YAML::BeginSeq ;
-        for ( Locale l : requestedLocales ) {
+        for ( const Locale& l : requestedLocales ) {
           yOut << YAML::Value << YAML::BeginMap;
           yOut << YAML::Key << "fate" << YAML::Value << ( addedLocales.count(l) ? "added" : "" ) ;
           yOut << YAML::Key << "name" << YAML::Value << l.asString() ;
           yOut << YAML::EndMap;
         }
 
-        for ( Locale l : removedLocales ) {
+        for ( const Locale& l : removedLocales ) {
           yOut << YAML::Value << YAML::BeginMap;
           yOut << YAML::Key << "fate" << YAML::Value << "removed" ;
           yOut << YAML::Key << "name" << YAML::Value << l.asString() ;
@@ -213,7 +214,7 @@ namespace zypp
 
         // Vendor settings
         yOut << YAML::Key << "vendors" << YAML::Value << YAML::BeginSeq ;
-        VendorAttr::instance().foreachVendorList( [&]( VendorAttr::VendorList vlist )->bool {
+        VendorAttr::instance().foreachVendorList( [&]( const VendorAttr::VendorList& vlist )->bool {
           if ( ! vlist.empty() ) {
             yOut << YAML::Value << YAML::BeginSeq;
             for( const auto & v : vlist )
