@@ -16,6 +16,7 @@
 #include <vector>
 #include <string>
 
+#include <zypp/Globals.h>
 #include <zypp/base/PtrTypes.h>
 #include <zypp/IdString.h>
 
@@ -32,7 +33,7 @@ namespace zypp
     //
     /** Hardware abstaction layer singleton.
      */
-    class Modalias
+    class ZYPP_API_DEPTESTOMATIC Modalias
     {
       friend std::ostream & operator<<( std::ostream & str, const Modalias & obj );
 
@@ -41,7 +42,7 @@ namespace zypp
         struct Impl;
 
       public:
-        typedef std::vector<std::string> ModaliasList;
+        using ModaliasList = std::vector<std::string>;
 
         /** Singleton access. */
         static Modalias & instance();
@@ -90,7 +91,7 @@ namespace zypp
     ///////////////////////////////////////////////////////////////////
 
     /** \relates Modalias Stream output */
-    std::ostream & operator<<( std::ostream & str, const Modalias & obj );
+    std::ostream & operator<<( std::ostream & str, const Modalias & obj ) ZYPP_API_DEPTESTOMATIC;
 
     /////////////////////////////////////////////////////////////////
   } // namespace target
