@@ -171,7 +171,7 @@ namespace zypp
       return _target;
     }
 
-    void ZYppImpl::changeTargetTo( Target_Ptr newtarget_r )
+    void ZYppImpl::changeTargetTo( const Target_Ptr& newtarget_r )
     {
       if ( _target && newtarget_r ) // bsc#1203760: Make sure the old target is deleted before a new one is created!
         INT << "2 active targets at the same time must not happen!" << endl;
@@ -295,7 +295,7 @@ namespace zypp
         return;
       }
 
-      char buf;
+      char buf = 0;
       while( zyppng::eintrSafeCall( read, sigFd, &buf, 1 ) > 0 )
         continue;
     }
@@ -340,12 +340,6 @@ namespace zypp
   } // namespace zypp_detail
   ///////////////////////////////////////////////////////////////////
 
-  Pathname myTmpDir()	// from TmpPath.h
-  {
-    static filesystem::TmpDir _tmpdir( filesystem::TmpPath::defaultLocation(), "zypp." );
-    return _tmpdir.path();
-  }
-
   /////////////////////////////////////////////////////////////////
 } // namespace zypp
 ///////////////////////////////////////////////////////////////////
